Remotior Sensus
===============

.. image:: https://img.shields.io/badge/Website-darkgreen
    :target: https://fromgistors.blogspot.com/p/remotior-sensus.html

.. image:: https://img.shields.io/badge/Documentation-blue
    :target: https://remotior-sensus.readthedocs.io

.. image:: https://img.shields.io/badge/Bug%20reports-red
    :target: https://github.com/semiautomaticgit/remotior_sensus/issues

.. image:: https://img.shields.io/pypi/v/remotior-sensus?label=PyPI%20version
    :target: https://pypi.org/project/remotior-sensus

.. image:: https://img.shields.io/pypi/dm/remotior-sensus?label=PyPI%20downloads
    :target: https://pypi.org/project/remotior-sensus

.. image:: https://img.shields.io/conda/v/conda-forge/remotior-sensus?label=Conda%20version
    :target: https://anaconda.org/conda-forge/remotior-sensus

.. image:: https://img.shields.io/conda/d/conda-forge/remotior-sensus?label=Conda%20downloads
    :target: https://anaconda.org/conda-forge/remotior-sensus

.. image:: https://img.shields.io/conda/l/conda-forge/remotior-sensus
    :target: https://www.gnu.org/licenses/

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.10038132.svg
    :target: https://doi.org/10.5281/zenodo.10038132

.. image:: https://colab.research.google.com/assets/colab-badge.svg
    :target: https://remotior-sensus.readthedocs.io/en/latest/quickstart.html

.. image:: _static/logo.png
    :width: 60pt
    :align: center


Remotior Sensus (which is Latin for "a more remote sense")
is a Python package that allows for the processing
of remote sensing images and GIS data.

**Source code:** https://github.com/semiautomaticgit/remotior_sensus

**Bug reports:** https://github.com/semiautomaticgit/remotior_sensus/issues



Documentation
_____________


.. toctree::
   :maxdepth: 3
   :titlesonly:

   introduction.rst
   installation.rst
   quickstart.rst
   basic_tutorials.rst
   api_tools.rst
   api_core.rst
   api.rst
   changelog.rst

`Except where otherwise noted, content of this work is licensed under a`
`Creative Commons Attribution-ShareAlike 4.0 International License
<http://creativecommons.org/licenses/by-sa/4.0/>`_.
